==> haskell-ansi-terminal-1.0.2-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal
version:              1.0.2
visibility:           public
id:                   ansi-terminal-1.0.2-HBeoENQnxizF4CvHZENnzA
key:                  ansi-terminal-1.0.2-HBeoENQnxizF4CvHZENnzA
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  3bb5f26f2b52a837c0bd8e07402d87e7
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-94tBGyEfSQUHisdUb8P9op:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal
hs-libraries:         HSansi-terminal-1.0.2-HBeoENQnxizF4CvHZENnzA
depends:
    ansi-terminal-types-0.11.5-94tBGyEfSQUHisdUb8P9op base-4.17.2.1
    colour-2.3.6-5Hdg5NZuPkoIAWxSFkdA0e

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-1.0.2-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal
version:              1.0.2
visibility:           public
id:                   ansi-terminal-1.0.2-D46JaHr1BfPBLAK7nuv4I
key:                  ansi-terminal-1.0.2-D46JaHr1BfPBLAK7nuv4I
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  eec154ac48b8f1f7d3ce8f127d9e8229
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-F8EZCTpEKcaGBDj7yMsHLt:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal
hs-libraries:         HSansi-terminal-1.0.2-D46JaHr1BfPBLAK7nuv4I
depends:
    ansi-terminal-types-0.11.5-F8EZCTpEKcaGBDj7yMsHLt base-4.17.2.1
    colour-2.3.6-Cnp0EOFOdvOB15fkdB7GSC

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
